function [llbnInput,sacc,RT] = compute_llbn(colOutp, llbnInput, sacc, thres,t,RT);
% takes COL-outputs as input to calculate an upward and downward sacc.
% component and a mean wanted saccade length (llbn act).
% llbnInput: N_Timesteps x 3 (horiz, vert, lengt)
% t: scalar, time step;
% RT: scalar, gives beginning of sacc;
% thres: scalar, value above which saccade is started

N_Timesteps=size(colOutp,1);
N_Nodes =   size(colOutp,2);
N_dim  =    size(colOutp,3);

horiz=0;
vert=0;
for dim=1:N_dim
    % dim 1 is perfect horizontal one with 0 vert. component. Rest has angle
    % with it, and therefore sin and cos with give horiz. & vert. components
    % of each dim. I simply sum outp. of each half of the axis (left & right
    % of middle) in an unweighted fashion
    act = sum(colOutp(t, 1:(N_Nodes/2-1), dim));
    horiz =horiz +act * cos( (dim-1)/N_dim*pi );
    vert = vert + act * sin( (dim-1)/N_dim*pi );
    
    act = sum(colOutp(t, (N_Nodes/2+1):N_Nodes, dim));
    horiz =horiz +act * cos( (dim-1+N_dim)/N_dim*pi );
    vert = vert + act * sin( (dim-1+N_dim)/N_dim*pi );
end
llbnInput(t,1)=horiz; % / (horiz^2+vert^2)^0.5;
llbnInput(t,2)=vert;  % / (horiz^2+vert^2)^0.5;
if RT>t   % if no saccade yet started, check if threshold crossed.
    if (abs(horiz)>thres || abs(vert)>thres)
        RT=t;  % threshold is crossed for first time. Rt is time step
        sacc=zeros(N_Timesteps-RT+1,3); % set sacc. array to right size
    end
%    act = sum(sum( colOutp(t,1:N_Nodes/2-20,:) )) + sum(sum( colOutp(t,N_Nodes/2+20:N_Nodes,:) ));
%    if (act>thres), RT=t;, end. DIT IS VOOR ALS SACC DOOR TOTACT IN MAP GETRIGGERD
end

if (t>RT && t<RT+50)
    % Calculate saccade.
    
    % First calculate how far saccade should go. Put outp. of nodes coding for
    % same distance together, irresp. of on which side of middle they are, and
    % take maximum
    actMax=0;
    sacDegs = 0;
    for node=1:N_Nodes/2-25   % -25 because else fix nodes strongest during express saccs
        distAct = sum(colOutp(t,node,:)) + sum(colOutp(t,N_Nodes-node,:));
        if (distAct>actMax)
            actMax=distAct;
            sacDegs=node;
        end
    end
    llbnInput(t,3)=sacDegs/(N_Nodes/2); % given as prop. of supcol-dims
    
    % Now calculate the step in the saccade
    sacc_t=t-RT; % The saccade starts counting from the first ms. after RT.
    % input is normalized horiz & vert components, so that len=1
    horiz= llbnInput(t,1) / (llbnInput(t,1)^2+llbnInput(t,2)^2)^0.5;
    vert = llbnInput(t,2) / (llbnInput(t,1)^2+llbnInput(t,2)^2)^0.5;
    degs = 3 * sqrt( exp(2 * llbnInput(t,3)*4 / 1.4) - 2 * exp(llbnInput(t,3)*4 / 1.4) + 1 );
    % Now calc. desired saccade, how far we already are, and what the error is.
    horSacWish =horiz * degs;
    vertSacWish= vert * degs;
    if(sacc_t>1) horSacMade=sacc(sacc_t-1,1);  else horSacMade=0;  end
    if(sacc_t>1) vertSacMade=sacc(sacc_t-1,2); else vertSacMade=0; end
    horErr = (horSacWish-horSacMade) / (1+ 0.05*abs(vertSacWish));
    vertErr= (vertSacWish-vertSacMade)/(1+ 0.05*abs(horSacWish));
       
    % following is Gisbergen formula to translate mm SupCol to vis. degs. Added
    % to form. as appeared in vanGis et al. ('87) is only '*4' = #mm SupCol
    % parameters based on vGisb et al ('81) mlb's & drives should all be pos.,
    % while err & sacMade are neg for saccs to right and down
    mlb_left=0;
    mlb_right=0;
    mlb_up=0;
    mlb_down=0;
    if (horErr > -2) mlb_left = 1100 * (1-exp(-(horErr+2)/10)); end
    if (horErr < 2) mlb_right = 1100 * (1-exp(-(-horErr+2)/10)); end
    if (vertErr > -2) mlb_up = 1100 * (1-exp(-(vertErr+2)/10));  end
    if (vertErr < 2) mlb_down = 1100 * (1-exp(-(-vertErr+2)/10)); end
    drive_left = max(mlb_left - mlb_right,0);
    drive_right= max(mlb_right - mlb_left,0);
    drive_up = max(mlb_up - mlb_down,0);
    drive_down= max(mlb_down - mlb_up,0);
    % 3rd col in sacc gives act of OPN. if OPN more active than error,
    % saccade is over. Last clause is to make sure it does not restart.
    if ((abs(vertErr)-sacc(sacc_t,3)<0 && abs(horErr)-sacc(sacc_t,3)<0) || sacc(sacc_t,3)==60)
        % Put endpoint in all further positions to be able to report it easily
        sacc(sacc_t:N_Timesteps-RT+1,1)=sacc(sacc_t-1,1);
        sacc(sacc_t:N_Timesteps-RT+1,2)=sacc(sacc_t-1,2);
        sacc(sacc_t:N_Timesteps-RT+1,3)=60;
    else
        % sacc not over...
        % TO SLOW DOWN SACCADES, CHANGE VALUE BY WHICH DRIVE DIVIDED. value
        % of vGisb is 1000, used to be 1300.
        sacc(sacc_t,1) = horSacMade + (drive_left-drive_right)/1500;
        sacc(sacc_t,2) = vertSacMade + (drive_up-drive_down)/1500;
        % formula below gives  activity of OPN (in vGisb: 60-latch of 5 ms ago).
        % The trigger is implicit out because its only function is to inhbit OPN at start sacc
        sacc(sacc_t+5,3) = 60 - 0.15 * (drive_left+drive_right+drive_up+drive_down);
    end        
end