function [Inputs] = exogeninput(Inputs,Tstart,Tend,Node,Strength)
% Computes the visual input generated by a stim presented at time step
% Tstart, with offset at time step Tend. Node indexes the location of the
% input (in the 1-Dim visual inputs array Inputs), Strength gives the
% strength (the basic form of the input is multiplied by Strength). Inputs
% is both input- and output argument, because visual inputs are modeled as
% additive - they are all saved on top of one another.

Tau1=1/5;
Tau2=1/6;
TauEnd=1/25;
% if Tstart>0 there is a start, if Tend<tot-iterats there is an end. Max. transient
% strength is a fixed 4* sustained strength. All paramvalues are calibrated upon
% each other. Check how the kernel will look before changing any of them!
if (Tstart>0)
    a = 100 * Tau1 * Tau2 / (Tau2 - Tau1);
    for t=Tstart:Tend
        Tstim=t-Tstart;
        Transient=a * (exp(-Tstim * Tau1) - exp(-Tstim * Tau2));
        % for t's that are beyond the initial rise, check whether transient is
        % larger than continuous part function, else make it continuous
        if (t>20) & (Transient<1) Transient=1; end
        Inputs(t,Node)= Inputs(t,Node) + Strength * Transient;
    end
else
    for t=1:Tend
        Transient = 1;
        Inputs(t,Node)= Inputs(t,Node) + Strength * Transient;
    end
end
if ((Tend+1)<size(Inputs,1))
    for t=(Tend+1):size(Inputs,1)
        Tstim = t - Tend;
        Inputs(t,Node)= Inputs(t,Node) + Strength * exp(-Tstim*TauEnd);
    end
end