function [StimMatrices] = inputwgtstosc(N_scNodes,N_Dim,CenterNodes, N_fefNodes,sigma)
%generates matrices that translate input from V1 and FEF to the SC.
N_inputs = N_fefNodes;
StimMatrices=zeros(N_inputs,N_scNodes,N_Dim);
for d=1:N_Dim
    % for each dim take midpoint as  
    StimMatrices(d,:,:)=spatinput(N_scNodes,N_Dim,CenterNodes,d,sigma);
end
% One after n_dim is the center point (dim doesn't matter, is same for all dims); 
StimMatrices(N_Dim+1,:,:)=spatinput(N_scNodes,N_Dim,N_scNodes/2,1,sigma);
% Snd after n_dim is for antisacc.; is opposite of where normal stim. is.
StimMatrices(N_Dim+2,:,:)=spatinput(N_scNodes,N_Dim,N_scNodes-CenterNodes,1,sigma);
% Trd after n_dim is for inhib all except center; is opposite of input to center point.
StimMatrices(N_Dim+3,:,:)=ones(1,N_scNodes,N_Dim)-StimMatrices(N_Dim+1,:,:);

function [Stim] = spatinput(N_scNodes,N_Dim,CenterNode,StimAxis,sigma)
% Creates a stimulus of D duration from time T on, ending with a US
Stim=zeros(1,N_scNodes,N_Dim);
Scaling = 100; % 1 mm = 200 nodes
for d=1:N_Dim
    for i=1:N_scNodes
        Dmm=distance(CenterNode,i,StimAxis,d,N_scNodes,N_Dim);
        % sigma_in=0.7^2; sigma_in changed because we use 500 units (was 1001 =.1225)
        Stim(1,i,d) = exp((-1*((Dmm/Scaling)^2))/(2*sigma));
    end
end

function [dt] = distance(X,Y,DimX,DimY,N_Nodes,NDim);
if (DimX == DimY)       % if on same dim...
    dt = abs(X - Y);        % ...dist=absolute node difference btw. the two.
else                    % else...
    X = X - 0.5*N_Nodes;    % go from abs node nr. to node nr. relative to middle
    Y = Y - 0.5*N_Nodes;
    %All dims cover 180 deg. Angle is dim's slice of 180 deg. * diff. btw. dim. nrs.
    Angle = pi/NDim*abs(DimX-DimY);
    dt = sqrt( X^2 + Y^2 - 2 * X * Y * cos(Angle));
end