function [FEF, COL] = iterate_model(FEF, COL, WgtsToSC,V1inputs,DLinputs,DL_mininputs,sacc,t);

% iterate_model takes layers and input vectors and transforms layer params via act funxs.
% FEF, COL: layer structs;    WgtsToSC: matrices that translate input
% coordinates to locs on SC map.  V1inputs: bottom up inputs to SC and FEF;
% DLinputs=topdown to FEF; DL_mininputs=topdown to SC (inhibition)
% LatInhStrength = const. of lateral inhib., Rest=how much act. remains
% from prev. iterat., t= time step we're at
delay_FEFSC=10;         % nr. ms btw. FEF neuron firing and effect at SC
Rest = exp(-1/25);      % remaining SC act. from t to t+1, -1/30 to apr. 9, '09
RestFEF = exp(-1/50);   % remaining SC act. from t to t+1, -1/30 to apr. 9, '09
latInhStrength = -0.01; % strength of latinhib in SC, was: -.01 to apr. 9, '09
latInhFEF = -1; % strength of latinhib in SC, was: -.01 to apr. 9, '09
SCbackFEF = 0; %.005;      % sterngth of SC inp to FEF. Was 0.01 to apr. 14, '09

if(sum(V1inputs)==-1)
    % If sum first inputs is -1, then assume that whole model must be reset.
    COL.NodeAct=zeros(1,COL.N_Node,COL.N_Dim);
    FEF.NodeAct=zeros(1,FEF.N_Node);
else
    % First calculate inputs to COL from V1 and FEF, then lateral inhibition,
    % then col-act as function of previous act, inputs, inhibition & lateral
    % inhib. (calculated on the basis of outputs in previous iteration).
    InputToSC=zeros(1,COL.N_Node,COL.N_Dim);
    for i=1:FEF.N_Node
        InputToSC = InputToSC + V1inputs(t,i) * WgtsToSC(i,:,:);
        if (t>delay_FEFSC+1) InputToSC = InputToSC + 2*FEF.NodeOutp(t-delay_FEFSC,i)*WgtsToSC(i,:,:); end
    end
    % squash input to [0-1]
    COL.NodeInp=1-1./exp(InputToSC./4);
    NegInputToSC=zeros(1,COL.N_Node,COL.N_Dim);
    if(sum(sum(sacc))>0)
        NegInputToSC=-0.1*sum(sum(sacc))*ones(1,COL.N_Node,COL.N_Dim);  
    end
    for i=1:FEF.N_Node
        NegInputToSC=NegInputToSC + sum(DL_mininputs(t,i),1) * WgtsToSC(i,:,:);
    end
    % All node inhib one another, but no node itself (that done in substraction at end)
    if (t>3) COL.LatInh = latInhStrength * (sum(sum(COL.NodeOutp(t-3,:,:)))*ones(1,COL.N_Node,COL.N_Dim)-COL.NodeOutp(t-3,:,:)); end
    %if(mod(t,10)==0),sum(sum(COL.NodeOutp(t-3,:,:))),end   % print sum of act in SC
    % Inhib. should be no bigger than 1.
    COL.LatInh = max(COL.LatInh,-1);
    % Nodeact is rest * old nodeact, plus input * distance to asymptote.
    COL.NodeAct(1,:,:) = COL.Default + Rest*(COL.NodeAct(1,:,:) -COL.Default) + (1-Rest)*(COL.NodeInp.*(7-COL.NodeAct(1,:,:)) + (COL.LatInh+NegInputToSC).*(1+COL.NodeAct(1,:,:)));
    COL.NodeAct(t,:,:) = COL.NodeAct(1,:,:);   % to keep track of activity
    COL.NodeOutp(t,:,:) = max(COL.NodeAct(1,:,:)-1,0);
    % central nodes overlap on all dimes, double, so need to be set to 0 on all but first dim.
    COL.NodeOutp(t,250:251,2:COL.N_Dim)=zeros(1,2,COL.N_Dim-1);
    % The following line is for an interrupted saccade.
    %if (t>309 & t<330),COL.NodeOutp(t,250:251,2:COL.N_Dim)=5*ones(1,2,COL.N_Dim-1); end

    % Now calculate input to FEF, also feedback from SC to FEF. Then squash to [0-1]
    InputToFEF=DLinputs(t,:)+ V1inputs(t,:);
    for i=1:FEF.N_Node
        if (t>delay_FEFSC+1) InputToFEF(1,i) = InputToFEF(1,i) + SCbackFEF*sum(sum(squeeze(COL.NodeOutp(t-delay_FEFSC,:,:)).*squeeze(WgtsToSC(i,:,:)))); end
    end
    FEF.NodeInp=1-1./exp(InputToFEF*2);
    
    % All node inhib one another, but no node itself (that done in substraction at end)
    FEF.Inh= min(zeros(1,FEF.N_Node),DL_mininputs(t,:)); % 'min' because anticip is coded as pos inhib, to be substracted from the SNr-inhib that does not arrive at FEF
    if (t>3) FEF.Inh = FEF.Inh + latInhFEF * (sum(FEF.NodeOutp(t-3,:))*ones(1,FEF.N_Node)-FEF.NodeOutp(t-3,:)); end
    % Nodeact is rest* old nodeact, plus input * distance to asymptote
    FEF.NodeAct = RestFEF*FEF.NodeAct + (1-RestFEF)*(FEF.NodeInp.*(7-FEF.NodeAct) + FEF.Inh.*(1+FEF.NodeAct));
    FEF.NodeAct(1,FEF.N_Node)=0; % last FEF node does not exist (is used for SNr-inhib)
    
    FEF.NodeOutp(t,:) = max(FEF.NodeAct(1,:)-1,0);
end