function[RT, sacc] = supcol(SIMUL,fixdlpfc,anticipdlpfc,distr_inh,V1D);
% supcol runs simul. for 1 paramset. INPUT ARGUMENTS: 
% SIMUL: name simulation - see generate_inputs for def. of simuls. 
% fixtopdown: strength DLPFC signal at fix before fix offset
% anticiptopdown: strength DLPFC inp. at targ. loc before targ onset
% distr_inh: inhibition at distr. loc
% V1D: bottom-up strength distractor inp (in V1)
% OUTPUT ARGS: RT: ms. of saccade start relative to start sim 
%              sacc: vector descr. saccade coordinates on each time step;
%                    see compute_llbn_sacc for how it is defined

thres = 35;     %  threshold for saccade elicitation

% Sizes of the model are set in generate_inputs, as they define input matrices
[V1inputs, DLinputs,DL_mininputs, N_Timesteps, N_Nodes, N_fefNode, N_Dim] = generate_inputs(SIMUL,fixdlpfc,anticipdlpfc,distr_inh,V1D);
[WgtsToSC] = inputwgtstosc(N_Nodes,N_Dim,floor(N_Nodes/4),N_fefNode,.11);
COL = initialize_col(N_Timesteps, N_Nodes, N_Dim);
FEF = initialize_fef(N_Timesteps, N_Dim+1,N_fefNode);
llbnInput=zeros(N_Timesteps,3);
RT = N_Timesteps;    % if there is no sacc, RT equal to last time step
sacc=zeros(1,2);

% Now run simulation.
for t = 1:N_Timesteps
     % if saccade started more than 10 ms ago, saccNow will be efferent copy of saccade
    if(t-10>RT) saccNow=sacc(t-10-RT,1:2); else saccNow=zeros(1,2); end
    [FEF, COL] = iterate_model(FEF, COL, WgtsToSC,V1inputs,DLinputs,DL_mininputs,saccNow,t);
    [llbnInput,sacc,RT] = compute_llbn_sacc(COL.NodeOutp, llbnInput,sacc,thres, t, RT);
end
%%%%%%%%%%%%%%%%%%%%%%%%%%
simple_output(FEF, COL,V1inputs,DLinputs);
strcat(SIMUL, ' ', num2str(RT))

% to save the saccade as it is made
%flurp=sacc(1:60,:)
%save results\saccade.txt flurp -ASCII;
            
%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [COL]=initialize_col(N_Timesteps, N_Nodes,N_Dim);
COL.NodeInp = zeros(1,N_Nodes,N_Dim);
COL.NodeAct = 0.5*ones(N_Timesteps,N_Nodes,N_Dim); % set node act at realistic value to reduce settling time
COL.NodeAccom = zeros(1,N_Nodes,N_Dim);
COL.Default = zeros(1,N_Nodes,N_Dim);    % rest act. of SC cells (not used)
COL.NodeOutp = zeros(N_Timesteps,N_Nodes,N_Dim);
COL.Inh = zeros(1,N_Nodes,N_Dim);
COL.LatInh = 0;
COL.N_Node = N_Nodes;
COL.N_Dim = N_Dim;

function [FEF]=initialize_fef(N_Timesteps, Fixnode, N_Nodes);
FEF.NodeInp = zeros(1,N_Nodes);
FEF.NodeAct = zeros(1,N_Nodes);
FEF.NodeAct(Fixnode) = 1.9; % set act for fix point to realistic value to reduce settling time
FEF.NodeAccom = zeros(1,N_Nodes);
FEF.NodeOutp = zeros(N_Timesteps,N_Nodes);
FEF.Inh = ones(1,N_Nodes);
FEF.N_Node = N_Nodes;